@@ -1,16 +1,16 @@
 # This file is encoded in ShiftJIS.
 die "This file is not encoded in ShiftJIS.\n" if q{} ne "\x82\xa0";
 
+use Sjis;
+
 local $^W = 1;
 
-unless (@ARGV) {
+if (@ARGV < 2) {
     die <<'END';
 s@:
 
-jperl55.bat grepdir.pl aaa dt
-jperl55.bat grepdir.pl \  dt
-jperl.exe   grepdir.pl aaa dt
-jperl.exe   grepdir.pl \  dt
+perl grepdir.pl aaa dt
+perl grepdir.pl \  dt
 END
 }
 
@@ -70,7 +70,7 @@ http://www.aritia.org/hizumi/perl/perlwin.html
 
 : K\w肵āCw肵fBNgz̃t@CoR[hĂB
 
-R}h`: jperl grepdir.pl {p^[} {fBNg}
+R}h`: perl grepdir.pl {p^[} {fBNg}
 
 ̂悤ȃeXgpӂB
 
@@ -86,9 +86,9 @@ alphabet
        alpha.txt
        sjis.txt
 
- jperl55.bat ɂĎsƁĈ悤ɂȂB
+ perl ɂĎsƁĈ悤ɂȂB
 
-C:\TEMP\TP\DT>jperl55.bat grepdir.pl aaa dt
+C:\TEMP\TP\DT>perl grepdir.pl aaa dt
 !!dt/alphabet!!
 !!dt/alphabet/alpha.txt!!
 dt/alphabet/alpha.txt:aaa
@@ -100,31 +100,7 @@ dt/{/alpha.txt:aaa
 !!dt/{/sjis.txt!!
 dt/{/sjis.txt:aaa
 
-C:\TEMP\TP\DT>jperl55.bat grepdir.pl \ dt
-!!dt\alphabet!!
-!!dt\alphabet\alpha.txt!!
-!!dt\alphabet\sjis.txt!!
-dt\alphabet\sjis.txt:\
-!!dt\{!!
-!!dt\{\alpha.txt!!
-!!dt\{\sjis.txt!!
-dt\{\sjis.txt:\
-
-Ql܂ł jperl.exe ɂĎsƁĈ悤ɂȂB
-
-C:\TEMP\TP\DT>jperl.exe grepdir.pl aaa dt
-!!dt\alphabet!!
-!!dt\alphabet\alpha.txt!!
-dt\alphabet\alpha.txt:aaa
-!!dt\alphabet\sjis.txt!!
-dt\alphabet\sjis.txt:aaa
-!!dt\{!!
-!!dt\{\alpha.txt!!
-dt\{\alpha.txt:aaa
-!!dt\{\sjis.txt!!
-dt\{\sjis.txt:aaa
-
-C:\TEMP\TP\DT>jperl.exe grepdir.pl \ dt
+C:\TEMP\TP\DT>perl grepdir.pl \ dt
 !!dt\alphabet!!
 !!dt\alphabet\alpha.txt!!
 !!dt\alphabet\sjis.txt!!
