@@ -1,6 +1,8 @@
 # This file is encoded in ShiftJIS.
 die "This file is not encoded in ShiftJIS.\n" if q{} ne "\x82\xa0";
 
+use Sjis;
+
 # }b`͂Ȃ̂Ƀ}b`ȂiPj
 if ("^]Ƌ" =~ m'^]') {
     print 1;
@@ -11,7 +13,7 @@ else {
 
 __END__
 
-esjis.pl ŏXNvg̎sʂȉɂȂ邱Ƃ҂Ă
+Sjis.pm ŏXNvg̎sʂȉɂȂ邱Ƃ҂Ă
 
 1
 
